diff inst/linear_algebra_backend.m @ 254:2b51546a28f7

Change default linear algebra back-end
author Eugenio Gianniti <eugenio.gianniti@mail.polimi.it>
date Sat, 26 Jul 2014 19:38:23 +0200
parents b1dc98050634
children 61830a4f9ab9
line wrap: on
line diff
--- a/inst/linear_algebra_backend.m	Tue Jul 29 18:05:56 2014 +0200
+++ b/inst/linear_algebra_backend.m	Sat Jul 26 19:38:23 2014 +0200
@@ -18,14 +18,14 @@
 ## @deftypefnx {Function File} @var{old_val} = linear_algebra_backend (@var{new_val})
 ##
 ## Query or set the internal variable that specifies the linear algebra back-end
 ## to use when assembling systems, matrices or vectors. It defaults to "uBLAS".
 ## uBLAS and PETSc are currently available.
 ##
 ## @end deftypefn
 
 function output = linear_algebra_backend (varargin)
 
-  persistent backend = "uBLAS";
+  persistent backend = "PETSc";
   persistent opts = {"uBLAS",
                      "PETSc"};
@@ -18,14 +18,14 @@
 ##
 ## Query or set the internal variable that specifies the linear algebra back-end
-## to use when assembling systems, matrices or vectors. It defaults to "uBLAS".
+## to use when assembling systems, matrices or vectors. It defaults to "PETSc".
 ## uBLAS and PETSc are currently available.
 ##